aboutsummaryrefslogtreecommitdiff
path: root/src/northbridge/intel/sandybridge/raminit_common.h
diff options
context:
space:
mode:
authorFelix Held <felix-coreboot@felixheld.de>2019-12-31 14:15:05 +0100
committerFelix Held <felix-coreboot@felixheld.de>2020-01-01 16:12:32 +0000
commitef4fe3e37c2741bec14b42ab37cddaa91342d232 (patch)
tree58eb7d59524c82f3e94ccef243eea0b641cafb3a /src/northbridge/intel/sandybridge/raminit_common.h
parent26be0bdbf67e348fa757fb516e5bf34663898d40 (diff)
nb/intel/sandybridge: replace .val_4028 with .io_latency
Change-Id: Id584028e99975f18c97780ca6b3c7988d9e84f45 Signed-off-by: Felix Held <felix-coreboot@felixheld.de> Reviewed-on: https://review.coreboot.org/c/coreboot/+/38027 Reviewed-by: Kyösti Mälkki <kyosti.malkki@gmail.com> Reviewed-by: Angel Pons <th3fanbus@gmail.com> Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
Diffstat (limited to 'src/northbridge/intel/sandybridge/raminit_common.h')
-rw-r--r--src/northbridge/intel/sandybridge/raminit_common.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/northbridge/intel/sandybridge/raminit_common.h b/src/northbridge/intel/sandybridge/raminit_common.h
index 6bbc8b3e0f..d11c04417a 100644
--- a/src/northbridge/intel/sandybridge/raminit_common.h
+++ b/src/northbridge/intel/sandybridge/raminit_common.h
@@ -54,8 +54,8 @@ typedef struct dimm_info_st {
struct ram_rank_timings {
/* Register 4024. One byte per slotrank. */
u8 val_4024;
- /* Register 4028. One nibble per slotrank. */
- u8 val_4028;
+ /* IO_LATENCY register. One nibble per slotrank. */
+ u8 io_latency;
int val_320c;